<?php

namespace App\Controller;

use App\Request\DetailRequest;
use App\Request\EmptyRequest;
use App\Request\NewsListingRequest;
use App\Service\NewsDetailService;
use App\Service\NewsListingService;
use App\Service\NewsMainNewsService;
use App\Service\NewsSearchService;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController as BundleController;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/api/v1/news')]
class NewsController extends BundleController
{
    public function __construct(
        private readonly NewsDetailService $detailService,
        private readonly NewsListingService $listingService,
        private readonly NewsMainNewsService $mainNewsService,
        private readonly NewsSearchService $searchService,
    ) {}

    #[Route('/', name: 'news', methods: ['GET'])]
    public function news(NewsListingRequest $request): JsonResponse
    {
        return (new Handle($this->listingService))->handle($request);
    }

    #[Route('/mainNews', name: 'mainNews', methods: ['GET'])]
    public function mainNews(EmptyRequest $request): JsonResponse
    {
        return (new Handle($this->mainNewsService))->handle($request);
    }

    #[Route('/search', name: 'searchNews', methods: ['GET'])]
    public function search(EmptyRequest $request): JsonResponse
    {
        return (new Handle($this->searchService))->handle($request);
    }

    #[Route('/{detailId}', name: 'oneNews', methods: ['GET'])]
    public function oneNews(DetailRequest $request): JsonResponse
    {
        return (new Handle($this->detailService))->handle($request);
    }
}
